{ config, pkgs, ... }:
let
    password = (import ./secrets.nix).settings.hashedPassword;
in
{
    users = {
      mutableUsers = false;
      groups.syncthing = {};
      groups.bitcoin = {};
      groups.localtimed = {};
      groups.tor = {};
      users.zuska = {
        isNormalUser = true;
        description = "zuska";
        extraGroups = [
          "dialout"
          "disk"
          "docker"
          "network"
          "nogroup"
          "systemd-journal"
          "systemd-network"
          "systemd-resolve"
          "systemd-timesync"
          "render"
          "video"
          "wheel"
        ];
        home = "/home/zuska";
        createHome = true;
        shell = pkgs.fish;
        hashedPassword = password;
       };
       users.bitcoin = {
         isSystemUser = true;
         group = "bitcoin";
         extraGroups = [ "tor" "systemd-network" "network" ];
       };
       users.syncthing = {
         isSystemUser = true;
         group = "syncthing";
         extraGroups = [ "systemd-network" "network" ];
       };
       users.localtimed = {
         isSystemUser = true;
         group = "localtimed";
       };
       users.nobody = {
         isSystemUser = true;
         group = "nogroup";
         extraGroups = ["video"];
       };
       users.tor = {
         isSystemUser = true;
         group = "tor";
         extraGroups = [ "disk" "systemd-network" "network"];
       };
    };

  # Select internationalisation properties.
  i18n = {
    supportedLocales = [ "en_US.UTF-8/UTF-8" "ru_RU.UTF-8/UTF-8" ];
    defaultLocale = "en_US.UTF-8";
  };
  console = {
    font = "Lat2-Terminus16";
    keyMap = "us";
  };
}
